@@ -1,9 +1,7 @@
 package Installer;
-BEGIN {
-  $Installer::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: What does it do? It installs stuff....
-$Installer::VERSION = '0.903';
+$Installer::VERSION = '0.904';
 use strict;
 use warnings;
 use Installer::Target;
@@ -12,13 +10,18 @@ use Cwd;
 our @functions = qw(
 
   run
+  copy
+  txt
+
   export
   unset
   url
   file
+  git
   perl
   cpanm
   pip
+  debian
   perldeps
   dzildeps
   postgres
@@ -40,6 +43,12 @@ sub import {
       );
       $installer_target->installation;
     };
+    *{"$pkg\::target"} = sub {
+      $Installer::Target::current;
+    };
+    *{"$pkg\::target_path"} = sub {
+      $Installer::Target::current->target_path(@_);
+    };
   }
   for my $command (@functions) {
     my $function = 'install_'.$command;
@@ -63,7 +72,7 @@ Installer - What does it do? It installs stuff....
 
 =head1 VERSION
 
-version 0.903
+version 0.904
 
 =head1 SYNOPSIS
 
